#!/usr/bin/env python
# vim: ai ts=4 sts=4 et sw=4

from .outgoing import DatabaseBackend  # noqa
